@@ -45,8 +45,26 @@
 ##   }
 ## }
 
+#' get.depictor
+#' 
+#' return an RcdkDepictor.
+#' 
+#' @param width Default. \code{200}
+#' @param height Default. \code{200}
+#' @param zoom Default. \code{1.3}
+#' @param style Default. \code{cow}
+#' @param annotate Default. \code{off}
+#' @param abbr Default. \code{on}
+#' @param suppressh Default. \code{TRUE}
+#' @param showTitle Default. \code{FALSE}
+#' @param smaLimit Default. \code{100}
+#' @param sma Default. \code{NULL}
+#' @param fillToFit Defailt. \code{FALSE}
+#' 
+#' @export
+#' 
 get.depictor <- function(width = 200, height = 200, zoom = 1.3, style = "cow", annotate = "off", abbr = "on",
-                         suppressh = TRUE, showTitle = FALSE, smaLimit = 100, sma = NULL) {
+                         suppressh = TRUE, showTitle = FALSE, smaLimit = 100, sma = NULL, fillToFit = FALSE) {
   if (is.null(sma)) sma <- ""
   return(.jnew("org/guha/rcdk/view/RcdkDepictor",
                as.integer(width),
@@ -58,14 +76,26 @@ get.depictor <- function(width = 200, height = 200, zoom = 1.3, style = "cow", a
                as.logical(suppressh),
                as.logical(showTitle),
                as.integer(smaLimit),
-               as.character(sma)))
+               as.character(sma),
+               as.logical(fillToFit)))
 }
 
+#' view.molecule.2d
+#' 
+#' Create a 2D depiction of a molecule. If there are more than
+#' one molecules supplied, return a grid woth \code{ncol} columns,.
+#' 
+#' @param molecule The molecule to query. Should be a `jobjRef` representing an `IAtomContainer`
+#' @param ncol Default \code{4}
+#' @param width Default \code{200}
+#' @param height Default \code{200}
+#' @param depictor Default \code{NULL}
+#' 
+#' @importFrom utils write.table
+#' @export 
 view.molecule.2d <- function(molecule, ncol = 4, width = 200, height = 200, depictor = NULL) {
   
-  if (class(molecule) != 'character' &&
-      class(molecule) != 'list' &&
-      class(molecule) != 'jobjRef') {
+  if (!class(molecule) %in% c('character', 'list', 'jobjRef')) {
     stop("Must supply a filename, single molecule object or list of molecule objects")
   }
 
@@ -83,12 +113,12 @@ view.molecule.2d <- function(molecule, ncol = 4, width = 200, height = 200, depi
   }
 
   ## if we got a file name, lets load all the molecules
-  if (class(molecule) == 'character') {
+  if (is(molecule, 'character')) {
     molecule <- load.molecules(molecule)
     if (length(molecule) == 1) molecule <- molecule[[1]]
   }
 
-  if (class(molecule) != 'list') { ## single molecule
+  if (!is(molecule, 'list')) { ## single molecule
     if (attr(molecule, "jclass") != 'org/openscience/cdk/interfaces/IAtomContainer') {
       stop("Supplied object should be a Java reference to an IAtomContainer")
     }
@@ -100,11 +130,11 @@ view.molecule.2d <- function(molecule, ncol = 4, width = 200, height = 200, depi
       else
         sma = depictor$getSma()
 
-      cmd <- sprintf('java -cp \"%s/cont/*:%s/cont/rcdk.jar\" org.guha.rcdk.app.OSXHelper viewMolecule2D "%s" %d %d %f %s %s %s %s %s %d "%s" &', rcdklibs, jarfile, smi,
+      cmd <- sprintf('java -cp \"%s/cont/*:%s/cont/rcdk.jar\" org.guha.rcdk.app.OSXHelper viewMolecule2D "%s" %d %d %f %s %s %s %s %s %d "%s" %d &', rcdklibs, jarfile, smi,
                      depictor$getWidth(), depictor$getHeight(),
                      depictor$getZoom(), depictor$getStyle(), depictor$getAnnotate(),
                      depictor$getAbbr(), depictor$isSuppressh(), depictor$isShowTitle(),
-                     depictor$getSmaLimit(), sma)
+                     depictor$getSmaLimit(), sma, depictor$getFillToFit())
       return(system(cmd))
     } else {
       v2d <- .jnew("org/guha/rcdk/view/ViewMolecule2D", molecule, as.integer(width), as.integer(height), depictor)
@@ -124,12 +154,12 @@ view.molecule.2d <- function(molecule, ncol = 4, width = 200, height = 200, depi
       } else {
         sma = depictor$getSma()
       }
-      cmd <- sprintf('java -cp \"%s/cont/*:%s/cont/rcdk.jar\" org.guha.rcdk.app.OSXHelper viewMolecule2Dtable "%s" %d %d %f %s %s %s %s %s %d "%s" %d &',
+      cmd <- sprintf('java -cp \"%s/cont/*:%s/cont/rcdk.jar\" org.guha.rcdk.app.OSXHelper viewMolecule2Dtable "%s" %d %d %f %s %s %s %s %s %d "%s" %d %d &',
                      rcdklibs, jarfile, tf,
                      depictor$getWidth(), depictor$getHeight(),
                      depictor$getZoom(), depictor$getStyle(), depictor$getAnnotate(),
                      depictor$getAbbr(), depictor$isSuppressh(), depictor$isShowTitle(),
-                     depictor$getSmaLimit(), sma,
+                     depictor$getSmaLimit(), sma, depictor$getFillToFit(),
                      ncol)
       return(system(cmd))
     } else {
@@ -140,12 +170,17 @@ view.molecule.2d <- function(molecule, ncol = 4, width = 200, height = 200, depi
   }
 }
 
-view.table <- function(molecules, dat, cellx = 200, celly = 200) {
-##  stop("Currently disabled")
-
-  if (cellx <= 0 || celly <= 0) {
-    stop("Invalid cell width or height specified")
-  }
+#' view.table
+#' 
+#' Create a tabular view of a set of molecules (in 2D) and associated data columns
+#' 
+#' @param molecules A list of molecule objects (`jobjRef` representing an `IAtomContainer`)
+#' @param dat The \code{data.frame} associated with the molecules, one per row
+#' @param depictor Default \code{NULL}
+#' 
+#' @importFrom utils write.table
+#' @export 
+view.table <- function(molecules, dat, depictor = NULL) {
 
   if (!is.list(molecules)) {
     stop("Must provide a list of molecule objects")
@@ -159,6 +194,9 @@ view.table <- function(molecules, dat, cellx = 200, celly = 200) {
     stop("The number of rows in datatable must be the same as the number of molecules")
   }
 
+  if (is.null(depictor))
+    depictor <- get.depictor()
+  
   if (is.null(names(dat))) cnames <- c('Molecule', paste('V',1:ncol(dat)), sep='')
   else cnames <- c('Molecule', names(dat))
 
@@ -187,14 +225,17 @@ view.table <- function(molecules, dat, cellx = 200, celly = 200) {
   ## now make our object table
   xval.arr <- .jarray(rows, "[Ljava/lang/Object;")
   obj <- .jnew("org/guha/rcdk/view/ViewMolecule2DDataTable",
-               molecules, carr, xval.arr)
-  .jcall(obj, "V", "setCellX", as.integer(cellx))
-  .jcall(obj, "V", "setCellY", as.integer(celly))
+               molecules, carr, xval.arr, depictor)
   .jcall(obj, "V", "display")
 }
 
 
-
+#' view.image.2d
+#' 
+#' @param molecule The molecule to display Should be a `jobjRef` representing an `IAtomContainer`
+#' @param depictor Default \code{NULL}
+#' 
+#' @export
 view.image.2d <- function(molecule, depictor = NULL) {
   if (is.null(depictor))
     depictor <- get.depictor()
@@ -205,6 +246,14 @@ view.image.2d <- function(molecule, depictor = NULL) {
   return(readPNG(bytes))
 }
 
+#' copy.image.to.clipboard
+#' 
+#' generate an image and make it available to the system
+#' clipboard.
+#' 
+#' @param molecule The molecule to query. Should be a `jobjRef` representing an `IAtomContainer`
+#' @param depictor Optional. Default \code{NULL}. Depictor from \code{get.depictor}
+#' @export
 copy.image.to.clipboard <-  function(molecule, depictor = NULL) {
   if (is.null(depictor))
     depictor <- get.depictor()
@@ -218,12 +267,12 @@ copy.image.to.clipboard <-  function(molecule, depictor = NULL) {
     } else {
       sma = depictor$getSma()
     }
-    cmd <- sprintf('java -cp %s/cont/*:%s/cont/rcdk.jar org.guha.rcdk.app.OSXHelper copyToClipboard "%s" %d %d %f %s %s %s %s %s %d %s',
+    cmd <- sprintf('java -cp %s/cont/*:%s/cont/rcdk.jar org.guha.rcdk.app.OSXHelper copyToClipboard "%s" %d %d %f %s %s %s %s %s %d %s %d',
                    rcdklibs, jarfile, smi,
                    depictor$getWidth(), depictor$getHeight(),
                    depictor$getZoom(), depictor$getStyle(), depictor$getAnnotate(),
                    depictor$getAbbr(), depictor$isSuppressh(), depictor$isShowTitle(),
-                   depictor$getSmaLimit(), sma)
+                   depictor$getSmaLimit(), sma, depictor$getFillToFit())
     return(system(cmd))
   }
   if (attr(molecule,"jclass") != "org/openscience/cdk/interfaces/IAtomContainer")
